@@ -1,7 +1,7 @@
 package Git::Bunch;
 
-our $DATE = '2016-06-16'; # DATE
-our $VERSION = '0.54'; # VERSION
+our $DATE = '2016-06-18'; # DATE
+our $VERSION = '0.55'; # VERSION
 
 use 5.010001;
 use strict;
@@ -282,10 +282,15 @@ sub _list {
         if (-d _) {
             if ($e->{name} =~ /\A\./) {
                 $e->{type} = 'd';
-            } elsif (-d "$e->{name}/.git") {
-                $e->{type} = 'r';
+
+                # to save stat() call, we assume any dir that does not start
+                # with dot to be a repo
+
+            #} elsif (-d "$e->{name}/.git") {
+            #    $e->{type} = 'r';
+
             } else {
-                $e->{type} = 'd';
+                $e->{type} = 'r';
             }
         } else {
             $e->{type} = 'f';
@@ -1021,7 +1026,7 @@ Git::Bunch - Manage gitbunch directory (directory which contain git repos)
 
 =head1 VERSION
 
-This document describes version 0.54 of Git::Bunch (from Perl distribution Git-Bunch), released on 2016-06-16.
+This document describes version 0.55 of Git::Bunch (from Perl distribution Git-Bunch), released on 2016-06-18.
 
 =head1 SYNOPSIS
 
@@ -1475,7 +1480,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Git-Bunch>
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Git-Bunch>.
+Source repository is at L<https://github.com/sharyanto/perl-Git-Bunch>.
 
 =head1 BUGS
 
